@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Mapping, Sequence, Union
 
 from .literals import (
     AccessPreviewStatusReasonCodeType,
@@ -344,7 +344,7 @@ _RequiredCloudTrailDetailsTypeDef = TypedDict(
     {
         "accessRole": str,
         "startTime": Union[datetime, str],
-        "trails": List["TrailTypeDef"],
+        "trails": Sequence["TrailTypeDef"],
     },
 )
 _OptionalCloudTrailDetailsTypeDef = TypedDict(
@@ -387,7 +387,7 @@ _RequiredCreateAccessPreviewRequestRequestTypeDef = TypedDict(
     "_RequiredCreateAccessPreviewRequestRequestTypeDef",
     {
         "analyzerArn": str,
-        "configurations": Dict[str, "ConfigurationTypeDef"],
+        "configurations": Mapping[str, "ConfigurationTypeDef"],
     },
 )
 _OptionalCreateAccessPreviewRequestRequestTypeDef = TypedDict(
@@ -424,9 +424,9 @@ _RequiredCreateAnalyzerRequestRequestTypeDef = TypedDict(
 _OptionalCreateAnalyzerRequestRequestTypeDef = TypedDict(
     "_OptionalCreateAnalyzerRequestRequestTypeDef",
     {
-        "archiveRules": List["InlineArchiveRuleTypeDef"],
+        "archiveRules": Sequence["InlineArchiveRuleTypeDef"],
         "clientToken": str,
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
@@ -450,7 +450,7 @@ _RequiredCreateArchiveRuleRequestRequestTypeDef = TypedDict(
     "_RequiredCreateArchiveRuleRequestRequestTypeDef",
     {
         "analyzerName": str,
-        "filter": Dict[str, "CriterionTypeDef"],
+        "filter": Mapping[str, "CriterionTypeDef"],
         "ruleName": str,
     },
 )
@@ -472,10 +472,10 @@ class CreateArchiveRuleRequestRequestTypeDef(
 CriterionTypeDef = TypedDict(
     "CriterionTypeDef",
     {
-        "contains": List[str],
-        "eq": List[str],
+        "contains": Sequence[str],
+        "eq": Sequence[str],
         "exists": bool,
-        "neq": List[str],
+        "neq": Sequence[str],
     },
     total=False,
 )
@@ -784,7 +784,7 @@ IamRoleConfigurationTypeDef = TypedDict(
 InlineArchiveRuleTypeDef = TypedDict(
     "InlineArchiveRuleTypeDef",
     {
-        "filter": Dict[str, "CriterionTypeDef"],
+        "filter": Mapping[str, "CriterionTypeDef"],
         "ruleName": str,
     },
 )
@@ -824,7 +824,7 @@ _RequiredKmsGrantConfigurationTypeDef = TypedDict(
     {
         "granteePrincipal": str,
         "issuingAccount": str,
-        "operations": List[KmsGrantOperationType],
+        "operations": Sequence[KmsGrantOperationType],
     },
 )
 _OptionalKmsGrantConfigurationTypeDef = TypedDict(
@@ -846,8 +846,8 @@ class KmsGrantConfigurationTypeDef(
 KmsGrantConstraintsTypeDef = TypedDict(
     "KmsGrantConstraintsTypeDef",
     {
-        "encryptionContextEquals": Dict[str, str],
-        "encryptionContextSubset": Dict[str, str],
+        "encryptionContextEquals": Mapping[str, str],
+        "encryptionContextSubset": Mapping[str, str],
     },
     total=False,
 )
@@ -855,8 +855,8 @@ KmsGrantConstraintsTypeDef = TypedDict(
 KmsKeyConfigurationTypeDef = TypedDict(
     "KmsKeyConfigurationTypeDef",
     {
-        "grants": List["KmsGrantConfigurationTypeDef"],
-        "keyPolicies": Dict[str, str],
+        "grants": Sequence["KmsGrantConfigurationTypeDef"],
+        "keyPolicies": Mapping[str, str],
     },
     total=False,
 )
@@ -871,7 +871,7 @@ _RequiredListAccessPreviewFindingsRequestRequestTypeDef = TypedDict(
 _OptionalListAccessPreviewFindingsRequestRequestTypeDef = TypedDict(
     "_OptionalListAccessPreviewFindingsRequestRequestTypeDef",
     {
-        "filter": Dict[str, "CriterionTypeDef"],
+        "filter": Mapping[str, "CriterionTypeDef"],
         "maxResults": int,
         "nextToken": str,
     },
@@ -1019,7 +1019,7 @@ _RequiredListFindingsRequestRequestTypeDef = TypedDict(
 _OptionalListFindingsRequestRequestTypeDef = TypedDict(
     "_OptionalListFindingsRequestRequestTypeDef",
     {
-        "filter": Dict[str, "CriterionTypeDef"],
+        "filter": Mapping[str, "CriterionTypeDef"],
         "maxResults": int,
         "nextToken": str,
         "sort": "SortCriteriaTypeDef",
@@ -1088,7 +1088,7 @@ LocationTypeDef = TypedDict(
 NetworkOriginConfigurationTypeDef = TypedDict(
     "NetworkOriginConfigurationTypeDef",
     {
-        "internetConfiguration": Dict[str, Any],
+        "internetConfiguration": Mapping[str, Any],
         "vpcConfiguration": "VpcConfigurationTypeDef",
     },
     total=False,
@@ -1185,8 +1185,8 @@ S3BucketAclGrantConfigurationTypeDef = TypedDict(
 S3BucketConfigurationTypeDef = TypedDict(
     "S3BucketConfigurationTypeDef",
     {
-        "accessPoints": Dict[str, "S3AccessPointConfigurationTypeDef"],
-        "bucketAclGrants": List["S3BucketAclGrantConfigurationTypeDef"],
+        "accessPoints": Mapping[str, "S3AccessPointConfigurationTypeDef"],
+        "bucketAclGrants": Sequence["S3BucketAclGrantConfigurationTypeDef"],
         "bucketPolicy": str,
         "bucketPublicAccessBlock": "S3PublicAccessBlockConfigurationTypeDef",
     },
@@ -1293,7 +1293,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
 )
 
@@ -1327,7 +1327,7 @@ _OptionalTrailTypeDef = TypedDict(
     "_OptionalTrailTypeDef",
     {
         "allRegions": bool,
-        "regions": List[str],
+        "regions": Sequence[str],
     },
     total=False,
 )
@@ -1341,7 +1341,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "tagKeys": List[str],
+        "tagKeys": Sequence[str],
     },
 )
 
@@ -1349,7 +1349,7 @@ _RequiredUpdateArchiveRuleRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateArchiveRuleRequestRequestTypeDef",
     {
         "analyzerName": str,
-        "filter": Dict[str, "CriterionTypeDef"],
+        "filter": Mapping[str, "CriterionTypeDef"],
         "ruleName": str,
     },
 )
@@ -1379,7 +1379,7 @@ _OptionalUpdateFindingsRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateFindingsRequestRequestTypeDef",
     {
         "clientToken": str,
-        "ids": List[str],
+        "ids": Sequence[str],
         "resourceArn": str,
     },
     total=False,
